%make_decay_rate_data
% Generates example decay rate data. Isotope is Iodine-131 which
% is a beta emmitter with a half life of  8 days. Iodine-131 is produced
% during the nuclear fission of Uranium. (Iodine -131 has an atomic
% number of 53, which means a neutron number of 78).
%
% https://www.geigercounter.org/radioactivity/isotopes.htm#Iodine-131
%
% LAST UPDATED by Andy French June 2019

function make_decay_rate_data

%Isotope
isotope = 'Iodine-131';

%Half life /days
half_life = 8.0;

%Initial count rate /Bq
A0 = 1000;

%Background count rate /Bq
B = 100;

%Random error fraction (to better model random errors in Iodine-131
%activity, we multiply the theoretical activity by a REF*U(0,1) ).
REF = 0.5;

%Time interval for measurements /days
N_half_lives = 6;
tmax = half_life*N_half_lives;

%Time between measue=rements /days
dt = 6/24;

%Fontsize
fsize = 18;

%

%Construct activity /Bq vs time /days data vectors
t = 0 : dt : tmax; N = length(t);
A = A0*2.^(-t/half_life) + B ;
r = -0.5 + rand(1,N);
A = A.*( 1 + REF*r ); A = ceil(A);

%Plot activity vs time
figure('color',[1 1 1],'name','radioactive decay curve');
plot(t,A,'+');
xlabel('time /days','fontsize',fsize);
ylabel('decay rate /Bq ','fontsize',fsize);
title(['decay rate of ',isotope,' /Bq'],'fontsize',fsize);
set(gca,'fontsize',fsize);
grid on;
ylim([0,max(A)]);
print( gcf, 'radioactive decay curve.png','-dpng','-r300');
close(gcf);

%Construct Excel file of time and activity
X{1,1} = 'Iodine-131 count rate';
X{2,1} = 'Start date 26th April 1986, Chernobyl location X123.';
X{4,1} = 'Time /days';
X{4,2} = 'Activity /Bq';
for n=1:N
    X{4+n,1} = t(n);
    X{4+n,2} = A(n);
end
xlswrite( 'iodine-131 activity.xls',X);

%End of code

